"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sender import Sender, SenderTypedDict
from gsmservice_gateway.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class AddSenderResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: SenderTypedDict


class AddSenderResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: Sender
