"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import BaseModel
from gsmservice_gateway.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetSubaccountDetailsRequestTypedDict(TypedDict):
    user_login: str
    r"""Login of the subaccount (user) to get the data for"""


class GetSubaccountDetailsRequest(BaseModel):
    user_login: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=True))
    ]
    r"""Login of the subaccount (user) to get the data for"""
