"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "gsmservice-gateway"
__version__: str = "3.1.1"
__openapi_doc_version__: str = "1.2.2"
__gen_version__: str = "2.716.5"
__user_agent__: str = "speakeasy-sdk/python 3.1.1 2.716.5 1.2.2 gsmservice-gateway"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
