"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gsmservice_gateway.types import BaseModel
from gsmservice_gateway.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class SetDefaultSenderRequestTypedDict(TypedDict):
    sender: str
    r"""Sender name to set as default"""


class SetDefaultSenderRequest(BaseModel):
    sender: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Sender name to set as default"""


class SetDefaultSenderResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class SetDefaultSenderResponse(BaseModel):
    headers: Dict[str, List[str]]
