"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .incomingmessage import IncomingMessage, IncomingMessageTypedDict
from gsmservice_gateway.types import BaseModel
from gsmservice_gateway.utils import FieldMetadata, QueryParamMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListIncomingMessagesRequestTypedDict(TypedDict):
    page: NotRequired[int]
    r"""Page number of results"""
    limit: NotRequired[int]
    r"""Number of results on one page"""


class ListIncomingMessagesRequest(BaseModel):
    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number of results"""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 10
    r"""Number of results on one page"""


class ListIncomingMessagesResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[IncomingMessageTypedDict]


class ListIncomingMessagesResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[IncomingMessage]
